@@ -211,12 +211,17 @@ class TestStandardRest:
             resp = [resp]
         for record in resp:
             for k, v in record.items():
-                _type = schema.get(k, {}).get('type')
-                if _type:
-                    if v not in FALSY_VALUES and not OUTPUT_MAP[_type](v):
-                        assert False, f'Output Key: {k}, Type: {_type}\nValue: {v}'
+                # If this is a sub key of a flattened key, ignore.
+                for k2 in schema:
+                    if k2.startswith(k) and k2.lstrip(k).startswith('_'):
+                        break
                 else:
-                    missing.append(k)
+                    _type = schema.get(k, {}).get('type')
+                    if _type:
+                        if v not in FALSY_VALUES and not OUTPUT_MAP[_type](v):
+                            assert False, f'Output Key: {k}, Type: {_type}\nValue: {v}'
+                    else:
+                        missing.append(k)
         if missing:
             assert False, f'Manifest is missing outputs: {missing}'
         return True
